pub struct PendingFeaturesRecv<Io> { /* private fields */ }Expand description
Type state for an initiator stream which has sent and received the stream header.
To continue stream setup, call recv_features.
Implementations
Sourceimpl<Io> PendingFeaturesRecv<Io>
impl<Io> PendingFeaturesRecv<Io>
Sourcepub fn header(&self) -> StreamHeader<'_>
pub fn header(&self) -> StreamHeader<'_>
The stream header contents as sent by the peer.
Sourcepub fn take_header(&mut self) -> StreamHeader<'static>
pub fn take_header(&mut self) -> StreamHeader<'static>
Extract the stream header contents as sent by the peer.
Sourceimpl<Io: AsyncBufRead + AsyncWrite + Unpin> PendingFeaturesRecv<Io>
impl<Io: AsyncBufRead + AsyncWrite + Unpin> PendingFeaturesRecv<Io>
Sourcepub async fn recv_features<T: FromXml + AsXml>(
self,
) -> Result<(StreamFeatures, XmlStream<Io, T>), RecvFeaturesError>
pub async fn recv_features<T: FromXml + AsXml>( self, ) -> Result<(StreamFeatures, XmlStream<Io, T>), RecvFeaturesError>
Receive the responder’s stream features.
After the stream features have been received, the stream can be used
for exchanging stream-level elements (stanzas or “nonzas”). The Rust
type for these elements must be given as type parameter T.
If the peer sends a stream error instead of features, the error is
returned as RecvFeaturesError::StreamError.
If the peer sends any payload which is neither stream features nor
a stream error, an io::Error with
InvalidData kind is returned.
Sourcepub fn skip_features<T: FromXml + AsXml>(self) -> XmlStream<Io, T>
pub fn skip_features<T: FromXml + AsXml>(self) -> XmlStream<Io, T>
Skip receiving the responder’s stream features.
The stream can be used for exchanging stream-level elements (stanzas
or “nonzas”). The Rust type for these elements must be given as type
parameter T.
Note: Using this on RFC 6120 compliant streams where stream features are sent after the stream header will cause a parse error down the road (because the feature stream element cannot be handled). The only place where this is useful is in XEP-0114 connections.